pub enum PeerState {
Disconnected,
Connecting,
Connected,
}Expand description
Endpoint-level peer connection state.
Variants
Disconnected
No local engine exists for this peer.
Connecting
A local engine exists and a hello message is waiting for peer confirmation.
Connected
At least one valid packet has been observed from the peer.