StdFrontend

Struct StdFrontend 

pub struct StdFrontend<T> { /* private fields */ }
Active std frontend adapter.

Implementations

Source

impl<T> StdFrontend<T>
where T: Read + Write,

pub fn new(io: T) -> Self

Creates a frontend adapter using default MSRT config.

pub fn with_config(io: T, config: EngineConfig) -> Self

Creates a frontend adapter using config.

pub fn peer_state(&self) -> PeerState

Returns the endpoint peer state.

pub const fn io(&self) -> &T

Returns a shared reference to the owned IO object.

pub fn io_mut(&mut self) -> &mut T

Returns a mutable reference to the owned IO object.

pub fn into_inner(self) -> T

Consumes the adapter and returns the owned IO object.

pub fn connect(&mut self) -> Result<()>

Starts a fresh frontend session.

pub fn disconnect(&mut self)

Drops the active frontend session.

pub fn send(&mut self, message: &[u8]) -> Result<bool>

Queues an application message.

pub fn receive_available(&mut self) -> Result<usize>

Reads currently available stream bytes and feeds them into MSRT.

This method is best used with nonblocking IO. WouldBlock is treated as no input.

pub fn poll(&mut self) -> Result<AdapterEvent>

Polls one adapter event and writes any pending transmit bytes.

pub fn tick(&mut self) -> Result<AdapterEvent>

Runs receive_available followed by poll.